use strict;
use warnings;
package App::Tapper::prove;
# git description: v0.001-2-gf48e438

BEGIN {
  $App::Tapper::prove::AUTHORITY = 'cpan:TAPPER';
}
{
  $App::Tapper::prove::VERSION = '0.002';
}
# ABSTRACT: Tapper - tprove - alternative 'prove' which reports results to Tapper


1;

__END__

=pod

=encoding utf-8

=head1 NAME

App::Tapper::prove - Tapper - tprove - alternative 'prove' which reports results to Tapper

See L<tprove|bin/tprove>.

=head1 AUTHOR

Steffen Schwigon <ss5@renormalist.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steffen Schwigon.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
